# Changelog for incuna-epatient-api

## 0.1.4

* Set `notified=True` when users have been notified.

## 0.1.3

* Include templates.

## 0.1.2

* Fix app config loaded too early.

## 0.1.1

* Add missing init file which prevents to have the management commands.

## 0.1.0

* Add management command to notify and delete users
